<?xml version="1.0" ?>

<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:dc="http://purl.org/dc/elements/1.1/"
    xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
    xmlns:rss="http://purl.org/rss/1.0/"
    xmlns:rss09="http://my.netscape.com/rdf/simple/0.9/"
    exclude-result-prefixes="xsl rdf dc rss rss09">
  <xsl:output method="xml" omit-xml-declaration="yes" indent="yes"/>
  <xsl:variable name="headingColor">#99FFFF</xsl:variable>
  <xsl:variable name="bgColor">#FFFFFF</xsl:variable>
  <xsl:variable name="hl">#CCCCCC</xsl:variable>
  <xsl:variable name="ul">#FFFFFF</xsl:variable>
  <xsl:template match="/">
    <table cellspacing="0" cellpadding="1" width="100%" border="0">

        <!-- Output image in header -->
      <xsl:apply-templates select="rdf:RDF/rss:image" />
      <xsl:apply-templates select="rdf:RDF/rss09:image" />
      <xsl:apply-templates select="rss/channel/image" />
        <!-- Output channel header -->
      <xsl:apply-templates select="rdf:RDF/rss:channel" />
      <xsl:apply-templates select="rdf:RDF/rss09:channel" />
      <xsl:apply-templates select="rss/channel" />

      <!-- Spacer -->
      <tr align="left" bgcolor="{$bgColor}">
        <td colspan="2">
          <xsl:text disable-output-escaping="yes">
            &amp;nbsp;
          </xsl:text>
        </td>
      </tr>
      <!-- Output items -->
      <tr align="left" bgcolor="{$headingColor}">
        <td colspan="2">
          <B>
            <font size="+1">Articles:</font>
          </B>
        </td>
      </tr>

      <xsl:apply-templates select="rdf:RDF/rss:item"/>
      <xsl:apply-templates select="rdf:RDF/rss09:item"/>
      <xsl:apply-templates select="rss/channel/item"/>

      <!-- Output textinput for RSS 0.9X and 1.0 -->
      <xsl:if test="rdf:RDF/rss:textinput">
      <!-- Spacer -->
        <tr align="left" bgcolor="{$bgColor}">
          <td colspan="2">
            <xsl:text disable-output-escaping="yes">
              &amp;nbsp;
            </xsl:text>
          </td>
        </tr>
        <xsl:apply-templates select="rdf:RDF/rss:textinput"/>
      </xsl:if>
      <xsl:if test="rdf:RDF/rss09:textinput">
      <!-- Spacer -->
        <tr align="left" bgcolor="{$bgColor}">
          <td colspan="2">
            <xsl:text disable-output-escaping="yes">
              &amp;nbsp;
            </xsl:text>
          </td>
        </tr>
        <xsl:apply-templates select="rdf:RDF/rss09:textinput"/>
      </xsl:if>
    </table>
  </xsl:template>

        <!-- Handle the various inputs for the channel elements -->
  <xsl:template match="rss:channel">
    <xsl:call-template name="buildChannel">
      <xsl:with-param name="title" select="rss:title"/>
      <xsl:with-param name="link" select="rss:link"/>
      <xsl:with-param name="description" select="rss:description"/>
    </xsl:call-template>
  </xsl:template>
  <xsl:template match="rss09:channel">
    <xsl:call-template name="buildChannel">
      <xsl:with-param name="title" select="rss09:title"/>
      <xsl:with-param name="link" select="rss09:link"/>
      <xsl:with-param name="description" select="rss09:description"/>
    </xsl:call-template>

  </xsl:template>
  <xsl:template match="rss/channel">
    <xsl:call-template name="buildChannel">
      <xsl:with-param name="title" select="title"/>
      <xsl:with-param name="link" select="link"/>
      <xsl:with-param name="description" select="description"/>
      <xsl:with-param name="date" select="lastBuildDate"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template name="buildChannel">
  <!-- parameters -->
    <xsl:param name="title"/>
    <xsl:param name="link"/>
    <xsl:param name="description"/>
    <xsl:param name="lastBuildDate"/>
    <!-- Create Channel table header -->
    <td align="left" width="35%">
      <font size="+1">
        <B>
          <a href="{$link}" target="_new">
            <xsl:value-of select="$title"/>
          </a>
        </B>
      </font>
    </td>
    <xsl:text disable-output-escaping="yes">
    &#60;/tr&#62;
  </xsl:text>
    <tr align="left" bgcolor="{$bgColor}">
      <td colspan="2">
        <font size="-1">
          <xsl:value-of select="$description"/>
          <xsl:if test="lastBuildDate != ''">
            <br/>
              Updated on:<xsl:value-of select="$lastBuildDate"/>
          </xsl:if>
        </font>
      </td>
    </tr>
  </xsl:template>

  <!-- Handle the image elements -->
  <xsl:template match="rss:image">
    <xsl:call-template name="buildImage">
      <xsl:with-param name="title" select="rss:title"/>
      <xsl:with-param name="link" select="rss:link"/>
      <xsl:with-param name="url" select="rss:url"/>
    </xsl:call-template>
  </xsl:template>
  <xsl:template match="rss09:image">
    <xsl:call-template name="buildImage">
      <xsl:with-param name="title" select="rss09:title"/>
      <xsl:with-param name="link" select="rss09:link"/>
      <xsl:with-param name="url" select="rss09:url"/>
    </xsl:call-template>

  </xsl:template>
  <xsl:template match="rss/channel/image">
    <xsl:call-template name="buildImage">
      <xsl:with-param name="title" select="title"/>
      <xsl:with-param name="link" select="link"/>
      <xsl:with-param name="url" select="url"/>
      <xsl:with-param name="width" select="width"/>
      <xsl:with-param name="height" select="height"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template name="buildImage">
  <!-- parameters -->
    <xsl:param name="title"/>
    <xsl:param name="link"/>
    <xsl:param name="url"/>
    <xsl:param name="width"/>
    <xsl:param name="height"/>
    <xsl:text disable-output-escaping="yes">&#60;tr align="left" bgcolor="</xsl:text><xsl:value-of select="$headingColor"/><xsl:text disable-output-escaping="yes">"&#62;</xsl:text>
      <td align="left" width="35%">
      <xsl:choose>
        <xsl:when test="link != ''">
          <xsl:choose>
            <xsl:when test="width != ''">
              <a href="{$link}"  target="_new">
                <img src="{$url}" alt="{$title}" height="{$height}" width="{$width}"/>
              </a>
            </xsl:when>
            <xsl:otherwise>
              <a href="{$link}" target="_new">
                <img src="{$url}" alt="{$title}"/>
              </a>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:when>
        <xsl:otherwise>
          <xsl:choose>
            <xsl:when test="width != ''">
              <img src="{$url}" alt="{$title}" height="{$height}" width="{$width}"/>
            </xsl:when>
            <xsl:otherwise>
              <img src="{$url}" alt="{$title}"/>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:otherwise>
      </xsl:choose>
    </td>
  </xsl:template>
  <!-- Handle the item elements -->
  <xsl:template match="rss09:item">
    <xsl:call-template name="createItem">
      <xsl:with-param name="title" select="rss09:title"/>
      <xsl:with-param name="link" select="rss09:link"/>
    </xsl:call-template>
  </xsl:template>
  <xsl:template match="rss:item">
    <xsl:call-template name="createItem">
      <xsl:with-param name="title" select="rss:title"/>
      <xsl:with-param name="link" select="rss:link"/>
      <xsl:with-param name="description" select="rss:description"/>
    </xsl:call-template>
  </xsl:template>
  <xsl:template match="rss/channel/item">
    <xsl:call-template name="createItem">
      <xsl:with-param name="title" select="title"/>
      <xsl:with-param name="link" select="link"/>
      <xsl:with-param name="description" select="description"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template name="createItem">
    <xsl:param name="title"/>
    <xsl:param name="link"/>
    <xsl:param name="description"/>
    <xsl:variable name="count" ><xsl:number value="position()" format="1"/></xsl:variable>
    <xsl:variable name="oddOrEven"><xsl:number value="$count mod 2" format="1"/> </xsl:variable>

    <tr align="left" bgcolor="{$headingColor}">
      <xsl:choose>
        <xsl:when test="$oddOrEven = 0">
          <td align="left" width="35%" bgColor="{$hl}" colspan="2">
            <a href="{$link}" target="_new">
              <xsl:value-of select="$title"/>
            </a>
            <br/>
            <font size="-1">
              <xsl:value-of select="$description"/>
            </font>
          </td>
        </xsl:when>
        <xsl:otherwise>
          <td align="left" width="35%" bgColor="{$ul}" colspan="2">
            <a href="{$link}" target="_new">
              <xsl:value-of select="$title"/>
            </a>
            <br/>
            <font size="-1">
              <xsl:value-of select="$description"/>
            </font>
          </td>
        </xsl:otherwise>
      </xsl:choose>
    </tr>
  </xsl:template>
        <!-- Handle the textinput element -->
  <xsl:template match="rss:textinput">
    <tr align="left" bgcolor="{$bgColor}">
      <xsl:call-template name="textInputBox">
        <xsl:with-param name="title" select="rss:title"/>
        <xsl:with-param name="link" select="rss:link"/>
        <xsl:with-param name="description" select="rss:description"/>
        <xsl:with-param name="name" select="rss:name"/>
      </xsl:call-template>
    </tr>
  </xsl:template>
  <xsl:template match="rss09:textinput">
    <tr align="left" bgcolor="{$bgColor}">
      <xsl:call-template name="textInputBox">
        <xsl:with-param name="title" select="rss09:title"/>
        <xsl:with-param name="link" select="rss09:link"/>
        <xsl:with-param name="description" select="rss09:description"/>
        <xsl:with-param name="name" select="rss09:name"/>
      </xsl:call-template>
    </tr>
  </xsl:template>
  <xsl:template name="textInputBox">
          <!-- parameters -->
    <xsl:param name="title"/>
    <xsl:param name="link"/>
    <xsl:param name="description"/>
    <xsl:param name="name"/>
    <br/>
    <tr align="left" bgcolor="{$bgColor}">
      <form METHOD="GET" ACTION="{$link}">
        <td align="left" width="35%" bgColor="{$bgColor}" colspan="2">
          <xsl:value-of select="$title"/>
          <input name="{$name}" type="text" size="35" length="500"/>
          <input type="submit" value="Search"/>
          <br/>
          <font size="-1">
            <i>
              <xsl:value-of select="$description"/>
            </i>
          </font>
        </td>
      </form>
    </tr>
  </xsl:template>
</xsl:stylesheet>
