/*
 * Please read the License Agreement and other supplemental license terms, if 
 * any, accompanying this software package before using any of the software 
 * provided.  If you do not agree to the terms of the License Agreement or any 
 * other supplemental terms, please promptly destroy or return the software to 
 * Sun Microsystems, Inc. 
 *
 * "CONFIDENTIAL AND PROPRIETARY" Copyright ? 2003 Sun Microsystems, Inc.
 * All rights reserved. 
 */

package com.sun.portal.providers.login;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.Cookie;
import java.util.Hashtable;
import java.net.URL;
import java.net.MalformedURLException;
import java.util.Enumeration;
import java.util.ResourceBundle;
import java.util.logging.Logger;
import java.util.logging.Level;

import com.sun.portal.providers.context.ProviderContext;
import com.sun.portal.providers.ProfileProviderAdapter;
import com.sun.portal.providers.ProviderException;
import com.sun.portal.providers.context.ProviderContextException;
import com.sun.portal.log.common.PortalLogger;

public class LoginProvider extends ProfileProviderAdapter {
    private ResourceBundle bundle = null;
    private static Logger logger = PortalLogger.getLogger (LoginProvider.class);
    public StringBuffer getContent(HttpServletRequest request,
                                   HttpServletResponse response)
            throws ProviderException {
        if (bundle == null) bundle = getResourceBundle();
        logger.finest("PSDT_CSPPL0001");

        StringBuffer content = new StringBuffer();
        Hashtable tagTable = new Hashtable();

        String fontFace = "";
        URL loginHelpUrl = null;
        fontFace = getStringProperty("fontFace1", "sans-serif");
        tagTable.put("fontFace1", fontFace);
        loginHelpUrl = getHelp(request, "loginHelpUrl");

        // are persistent cookies enabled?
        // note: if the property returns true, it
        // must also be the case the the authentication
        // service is set to accept persistent cookies

        StringBuffer persistent = new StringBuffer();
        boolean pc = getBooleanProperty("persistentCookie");

        if (pc) {
            logger.finest("PSDT_CSPPL0002");
            persistent = getTemplate("persistentCookie.template", tagTable);
        } else
            persistent.append("");

        tagTable.put("persistentCookie", persistent.toString());
        if (loginHelpUrl != null) {
            tagTable.put("loginHelpUrl", loginHelpUrl.toString());
        }

        StringBuffer libertyLogin = new StringBuffer();
        boolean federationEnabled = false;
        try {
            if (getProviderContext().getProviderVersion(getName()) >= 2) {
                federationEnabled = getBooleanProperty("federationEnabled");
            }
        } catch (ProviderContextException pce) {
            logger.log(Level.FINE, "PSDT_CSPPL0003", pce);
            throw new ProviderException("LoginProvider.getContent():Exception getting login provider version", pce);
        }

        if (federationEnabled) {
            String preLoginURL = getStringProperty("preLoginURL", "/portal/dt");
            tagTable.put("preLoginURL", preLoginURL);
            logger.finest("PSDT_CSPPL0004");
            libertyLogin = getTemplate("libertyLogin.template", tagTable);
        } else {
            libertyLogin.append("");
        }

        tagTable.put("libertyLogin", libertyLogin.toString());

        //get the login url from provider context
        String loginUrl = getProviderContext().getLoginURL();
        tagTable.put("loginURL", loginUrl);
        tagTable.put("channelName", getName());
        content = getTemplate("display.template", tagTable);
        return content;

    }

    /**
     * isPresentable() returns true if the template for the front page
     * of the provider exists and returns false if it doesn't exist
     */
    public boolean isPresentable(HttpServletRequest request) {
        boolean isPresentable = false;
        ProviderContext pc = getProviderContext();
        try {
            if ((getTemplatePath("display.template") != null)) {
                isPresentable = true;
            }
        } catch (Exception pe) {
            logger.log(Level.INFO,"PSDT_CSPPL0005", pe );
        }
        return isPresentable;
    }

}
