#!/bin/sh

# Script to configure the SP
# This script MUST be customized before executing
# This script is executed as root on the system to be used as SP
# It requires following files:
# spmetadata.xml
# fedChannel.xml
# fedChannel.template
# commonLoginChannel.xml

####################**IMPORTANT**#####################
# All these values must be specified before running the script
# Edit these values and then run the script
######################################################
ROOT_SUFFIX="dc=sun,dc=com"
ORG_DN="o=DeveloperSample,$ROOT_SUFFIX"
PORTAL_ID="portal1"
IDP_HOST_DOMAIN="hostB.sun.com"
IDP_PORT="58080"
SP_HOST_DOMAIN="hostA.sun.com"
SP_PORT="58080"
PROTOCOL="http"
PASSWORD="11111111"    #amAdmin password
IDSAME_BASEDIR="/opt"
PORTAL_BASEDIR="/opt"
IS_DEPLOY_DESCRIPTOR="amserver"
PS_DEPLOY_DESCRIPTOR="portal"
COOKIE_DOMAIN=".sun.com"
CHANNEL_FILE_DIR="/var/opt/SUNWportal/portals/$PORTAL_ID/desktop/developer_sample/Federation"
CHANNEL_FILE="$CHANNEL_FILE_DIR/display.template"
PASSWORD_FILE="/tmp/password.$$"

######################################################
# These values may be edited, if required.
######################################################
ADMIN_DN="uid=amAdmin,ou=People,$ROOT_SUFFIX"
AUTHLESSANON_DN="uid=devauthlessanonymous,ou=People,$ORG_DN"

######################################################
# Command definitions
######################################################
AMADMIN=$IDSAME_BASEDIR/SUNWam/bin/amadmin
PSADMIN=$PORTAL_BASEDIR/SUNWportal/bin/psadmin
RM="/usr/bin/rm -f"
CP=/usr/bin/cp
MKDIR=/usr/bin/mkdir
SED=/usr/bin/sed
CAT=/usr/bin/cat

######################################################
# Create Password File
######################################################
create_password_file() {
echo "$PASSWORD" > $PASSWORD_FILE
}

######################################################
# Remove Password File
######################################################
remove_password_file() {
$RM $PASSWORD_FILE
}

######################################################
# Load sp metadata
######################################################
load_sp_metadata() {
echo "Loading SP metadata..."

FILE="/tmp/spmetadata.xml"
$SED -e "s/\$ORG_DN/$ORG_DN/g" \
     -e "s/\$PROTOCOL/$PROTOCOL/g" \
     -e "s/\$SP_HOST_DOMAIN/$SP_HOST_DOMAIN/g" \
     -e "s/\$SP_PORT/$SP_PORT/g" \
     -e "s/\$IS_DEPLOY_DESCRIPTOR/$IS_DEPLOY_DESCRIPTOR/g" \
     -e "s/\$PS_DEPLOY_DESCRIPTOR/$PS_DEPLOY_DESCRIPTOR/g" \
     -e "s/\$IDP_HOST_DOMAIN/$IDP_HOST_DOMAIN/g" \
     -e "s/\$IDP_PORT/$IDP_PORT/g" \
     -e "s/\$COOKIE_DOMAIN/$COOKIE_DOMAIN/g" \
     spmetadata.xml > $FILE

$AMADMIN --runasdn $ADMIN_DN --password "$PASSWORD" -v --data $FILE
$RM $FILE
}

######################################################
# Create Federation Channel
######################################################
create_fed_channel() {
echo "Creating Federation Channel..."

FILE="/tmp/fedChannel.xml"
$SED -e "s/\$PROTOCOL/$PROTOCOL/g" \
     -e "s/\$SP_HOST_DOMAIN/$SP_HOST_DOMAIN/g" \
     -e "s/\$SP_PORT/$SP_PORT/g" \
     -e "s/\$IS_DEPLOY_DESCRIPTOR/$IS_DEPLOY_DESCRIPTOR/g" \
     fedChannel.xml > $FILE

#modify dp
$PSADMIN modify-dp --adminuser "$ADMIN_DN" --passwordfile "$PASSWORD_FILE" -m --portal "$PORTAL_ID" --dn "$ORG_DN" $FILE
$RM $FILE

#copy the channel template
if [ -f $CHANNEL_FILE ]; then
    echo "Federation channel template already exists."
    return
else
    echo "Creating federation channel template..."
    $MKDIR $CHANNEL_FILE_DIR
    $CP fedChannel.template $CHANNEL_FILE
fi
}

######################################################
# Set Global Attributes for Desktop Service
######################################################
set_desktop_svc_attrs() {
echo "Setting desktop service attributes..."

$PSADMIN set-attribute --adminuser "$ADMIN_DN" --passwordfile "$PASSWORD_FILE" --portal "$PORTAL_ID" --component desktop --attribute-name EnableAuthless true
$PSADMIN set-attribute --adminuser "$ADMIN_DN" --passwordfile "$PASSWORD_FILE" --portal "$PORTAL_ID" --component desktop --attribute-name EnableFederation true
$PSADMIN set-attribute --adminuser "$ADMIN_DN" --passwordfile "$PASSWORD_FILE" --portal "$PORTAL_ID" --component desktop --attribute-name DisableAuthlessForFederatedUsers false
$PSADMIN set-attribute --adminuser "$ADMIN_DN" --passwordfile "$PASSWORD_FILE" --portal "$PORTAL_ID" --component desktop --attribute-name HostedProviderId "$PROTOCOL://$SP_HOST_DOMAIN"

}

######################################################
# Create Common Login Channel for authlessanonymous user
######################################################
create_commonlogin_channel() {
echo "Creating Common Login channel for anonymous user..."

#modify dp
$PSADMIN modify-dp --adminuser "$ADMIN_DN" --passwordfile "$PASSWORD_FILE" -m --portal "$PORTAL_ID" --dn "$AUTHLESSANON_DN" << EOF
<?xml version="1.0" encoding="utf-8" standalone="no"?>
<!DOCTYPE DisplayProfile SYSTEM "jar://resources/psdp.dtd">

<DisplayProfile version="1.0" priority="10">
    <Properties/>
    <Channels>
        <Container name="MyFrontPageTabPanelContainer" provider="JSPTableContainerProvider">
            <Properties/>
            <Available>
                <Reference value="CommonLogin"/>
            </Available>
            <Selected>
                <Reference value="CommonLogin"/>
            </Selected>
            <Channels>
            </Channels>
        </Container>
        <Channel name="CommonLogin" provider="URLScraperProvider">
            <Properties>
                <String name="url" value="$PROTOCOL://$SP_HOST_DOMAIN:$SP_PORT/$IS_DEPLOY_DESCRIPTOR/config/federation/default/CommonLogin.jsp?metaAlias=$SP_HOST_DOMAIN"/>
                <String name="title" value="Common Login Channel"/>
                <String name="description" value="This channels lists all the trusted IDPs"/>
            </Properties>
        </Channel>
    </Channels>
    <Providers>
    </Providers>
</DisplayProfile>
EOF

}

######################################################
# Set Login channel properties for authlessanonymous user
######################################################
set_loginchannel_properties() {
echo "Setting Login channel properties for anonymous user..."

$PSADMIN modify-dp --parent Login --adminuser "$ADMIN_DN" --passwordfile "$PASSWORD_FILE" -m --portal "$PORTAL_ID" --dn "$AUTHLESSANON_DN" << EOF
<?xml version="1.0" encoding="utf-8" standalone="no"?> 
<!DOCTYPE DisplayProfile SYSTEM "jar://resources/psdp.dtd"> 

    <Properties> 
        <Boolean name="federationEnabled" value="true"/> 
        <String name="preLoginURL" value="$PROTOCOL://$SP_HOST_DOMAIN:$SP_PORT/$IS_DEPLOY_DESCRIPTOR/preLogin?metaAlias=$SP_HOST_DOMAIN&amp;goto=$PROTOCOL://$SP_HOST_DOMAIN:$SP_PORT/$PS_DEPLOY_DESCRIPTOR/dt"/> 
    </Properties> 
EOF

}

######################################################
# Create a portal server user "psuser" on SP hostA
######################################################
create_sp_user() {
echo "Creating user=psuser with password=psuser..."

FILE="/tmp/request.xml"
$CAT > $FILE << EOF 
<?xml version="1.0" encoding="ISO-8859-1"?>
<!DOCTYPE Requests
    PUBLIC "-//iPlanet//Sun ONE Identity Server 6.0 Admin CLI DTD//EN"
    "file:$IDSAME_BASEDIR/SUNWam/dtd/amAdmin.dtd">

<Requests>    
    <PeopleContainerRequests DN="ou=People,$ORG_DN">
      <CreateUser createDN="psuser">
        <AttributeValuePair>
          <Attribute name="userPassword"/>
          <Value>psuser</Value>
        </AttributeValuePair>
        <AttributeValuePair>
          <Attribute name="sn"/>
          <Value>psuser</Value>
        </AttributeValuePair>
        <AttributeValuePair>
          <Attribute name="cn"/>
          <Value>psuser</Value>
        </AttributeValuePair>
      </CreateUser>
    </PeopleContainerRequests>
</Requests>
EOF

$AMADMIN --runasdn $ADMIN_DN --password "$PASSWORD" -v --data $FILE
$RM $FILE
}

######################################################
#  Main
######################################################
create_password_file
load_sp_metadata
create_fed_channel
set_desktop_svc_attrs
create_commonlogin_channel
set_loginchannel_properties
create_sp_user
remove_password_file
